#!/usr/bin/ksh

###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T10
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

#
# $Header: /net/klstor01/datavol/gateways/da/CVSROOT/modules/MOTOROLA/scripts/set_mtcdma.ksh,v 1.3 2008/06/03 03:10:50 alamshi Exp $
#
# USAGE:    set_mtcdma.ksh <config_file>
#
# FUNCTION:   For each data collection specified in Motorola cdma config_file,
#         this script will create the following:
#             data directories
#             log directories
#             icf configuration file
#             icf checkpoint file
#             DA monitor file
#             Password lookup file
#         And one cron file in the ${FLEXDAHOME}/cfg directory
#

#
# Display usage message
#

usage()
{
echo "Usage: ${cmd} <config_file>"
echo "     <config_file> is the Motorola cdma configuration file"
exit 1
}


################################################################################
# create_file -- Backup existing file before overwriting
################################################################################
create_file() {

    typeset fd=$1
    typeset file=$2
	action="Creating"

    if [ -f $file ]
    then
		test -d $SAVEDIR || mkdir -p $SAVEDIR
		cp $file $SAVEDIR
		action="Modifying"
    fi

    if [ $fd -gt 2 ]
    then
	# This results to an IO malfunction
	# fcmd="exec $fd>$file"
	# eval $cmd
	# This one works but not pretty!
	case $fd in
	    3) exec 3>$file;;
	    4) exec 4>$file;;
	    5) exec 5>$file;;
	    6) exec 6>$file;;
	    7) exec 7>$file;;
	    8) exec 8>$file;;
	    9) exec 9>$file;;
	esac
    fi

    echo "${cmd}: ${action} $(basename $file) file"
    echo; sleep 1
}


#
# Prints ICF common information
#

print_common_icf()
{
typeset fd=${1:-1}
typeset title=${2:-"FlexDA ICF Configuration File"}
typeset market=${3:-"goodmarket"}
typeset netype=${4:-"netype"}
typeset neid=${5:-"neid"}
typeset dtype=${6:-"dtype"}

print -u$fd "#"
print -u$fd "# TITLE:   $title"
print -u$fd "#"
print -u$fd "# SITE:    $FLEXDASITE"
print -u$fd "#"
print -u$fd "# HOST:    $HOST"
print -u$fd "#"
print -u$fd "#"
print -u$fd "# ICF_CHAT Variables:"
print -u$fd "#"
print -u$fd "#    ICFBIN        Location of ICF binaries."
print -u$fd "#    ICFSCRIPT     Location of ICF scripts."
print -u$fd "#    ICFTABLE      Filename of ICF checkpoint table."
print -u$fd "#    ICFAPP        Filename of ICF application."
print -u$fd "#"
print -u$fd ""
print -u$fd "set MARKET         \"$market\""
print -u$fd "set NETYPE         \"$netype\""
print -u$fd "set NEID           \"$neid\""
print -u$fd "set DTYPE          \"$dtype\""
print -u$fd 'set TARGET         "$NEID.$NETYPE"'
print -u$fd ""
print -u$fd 'set ICFBIN         "$env(FLEXDAHOME)/bin"'
print -u$fd 'set ICFSCRIPT      "$env(FLEXDAHOME)/scripts"'
print -u$fd 'set ICFTABLE       "$env(FLEXDAHOME)/log/$MARKET.$TARGET.chk"'
case $dtype in
  sar )                     print -u$fd 'set ICFAPP         "$ICFSCRIPT/motsardist.exp"';;
  evdopm )                  print -u$fd 'set ICFAPP         "$ICFSCRIPT/motevdopmdist.exp"';;
  evdopmemh )               print -u$fd 'set ICFAPP         "$ICFSCRIPT/motevdopmemhdist.exp"';;
  evdocdl )                 print -u$fd 'set ICFAPP         "$ICFSCRIPT/motevdocdldist.exp"';;
  evdoconfigmap)            print -u$fd 'set ICFAPP         "$ICFSCRIPT/motevdocfgmapdist.exp"';;
  evdoecdl )                print -u$fd 'set ICFAPP         "$ICFSCRIPT/motevdoecdldist.exp"';;
  pmserver )                print -u$fd 'set ICFAPP         "$ICFSCRIPT/motpmserverdist.exp"';;
  aemsc13|aemsc2|aemsc4|aemsc6 )   print -u$fd 'set ICFAPP         "$ICFSCRIPT/motaemsdist.exp"';;
  kcicfg )                  print -u$fd 'set ICFAPP         "$ICFSCRIPT/motkcicfgdist.exp"';;
  anpm10min )               print -u$fd 'set ICFAPP         "$ICFSCRIPT/motanpm10mindist.exp"';;
  aemsc10min )              print -u$fd 'set ICFAPP         "$ICFSCRIPT/motaems10mindist.exp"';;
  *)                        print -u$fd 'set ICFAPP         "$ICFSCRIPT/$DTYPE.exp"';;
esac
print -u$fd ""
}


#
# Prints ICF's targethost/destination information
#

print_thost_icf()
{
typeset fd=${1:-1}
typeset tip=${2:-tip}
typeset tuser=${3:-tuser}
typeset tpswd=${4:-tpswd}
typeset tdir=${5:-tdir}

print -u$fd "#"
print -u$fd "# Target Prospect Server Variables"
print -u$fd "#"
print -u$fd "#    FLEXPMHOST    Address of WatchMark Prospect server"
print -u$fd "#    FLEXUSER      User account on WatchMark Prospect server"
print -u$fd "#    FLEXPSWD      User password on WatchMark Prospect server"
print -u$fd "#    FLEXDIR       Prospect server dist destination directory"
print -u$fd ""
print -u$fd "set FLEXPMHOST     \"$tip\""
print -u$fd "set FLEXUSER       \"$tuser\""
print -u$fd "set FLEXPSWD       {$tpswd}"
print -u$fd "set FLEXDIR        \"$tdir\""
print -u$fd ""
}

#
# Prints ICF's targethost/destination information
#

print_thost_icf_cdl()
{
typeset fd=${1:-1}
typeset tip=${2:-tip}
typeset tuser=${3:-tuser}
typeset tpswd=${4:-tpswd}
typeset tdir=${5:-tdir}

print -u$fd "#"
print -u$fd "# Target Prospect Server Variables"
print -u$fd "#"
print -u$fd "#    FLEXPMHOST    Address of WatchMark Prospect server"
print -u$fd "#    FLEXUSER      User account on WatchMark Prospect server"
print -u$fd "#    FLEXPSWD      User password on WatchMark Prospect server"
print -u$fd "#    FLEXDIR       Prospect server dist destination directory"
print -u$fd ""
print -u$fd "FLEXPMHOST     $tip"
print -u$fd "FLEXUSER       $tuser"
print -u$fd "FLEXPSWD       $tpswd"
print -u$fd "FLEXDIR        $tdir"
print -u$fd ""
}

#
# Prints sm tm icf
#

print_smtm_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-mscid}
typeset swid=${6:-swid}
typeset behind=${7:-behind}
typeset delay=${8:-delay}
typeset timeout=${9:-timeout}
typeset ignbef=${10:-c0}
typeset ignaft=${11:-c0}
typeset version=${12:-version}
typeset smrepddcfg=${13:-smrepddcfg}
typeset smscriptsdir=${14:-smscriptsdir}
typeset ndays=${15:-2}
typeset pastdays=${16:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    ICFDELAY      Number of seconds to delay between intervals"
print -u$fd "#    ICFIGNBEF     Don't collect data before this hour"
print -u$fd "#    ICFIGNAFT     Don't collect data after this hour"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    TIMEOUT       Number of seconds to wait for TMM scripts to finish"
print -u$fd "#    MSCID         MSC name of switch associated with this SwitchMate"
print -u$fd "#    SWID          MSC number of switch associated with this SwitchMate"
print -u$fd "#    EMX_VERSION   Software release of MSC switch"
print -u$fd "#    SMREPDDCFG    Report Data Dictionary (format) for SM TMM reports"
print -u$fd "#    SMSCRIPTSDIR  Directory location of scripts for SM TMM reports"
print -u$fd "#    C04DCOLLHRS   C04D TMM records special collection periods"
print -u$fd "#    TMMRECORDS    TMM CA/C0 records"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set ICFBEHIND      \"$behind\""
print -u$fd "set ICFDELAY       \"$delay\""
if ([ "$ignbef" == "-1" ])
then
    print -u$fd "set ICFIGNBEF      \"0\""
else
    print -u$fd "set ICFIGNBEF      \"$ignbef\""
fi
if ([ "$ignaft" == "-1" ])
then
    print -u$fd "set ICFIGNAFT      \"23\""
else
    print -u$fd "set ICFIGNAFT      \"$ignaft\""
fi
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set TIMEOUT        \"$timeout\""
print -u$fd "set MSCID          \"$srcid\""
print -u$fd "set SWID           \"$swid\""
print -u$fd "set EMX_VERSION    \"$version\""
print -u$fd "set SMREPDDCFG     \"$smrepddcfg\""
print -u$fd "set SMSCRIPTSDIR   \"$smscriptsdir\""
print -u$fd "set C04DCOLLHRS    \"0530 1130 1730 2330\""
print -u$fd "set TMMRECORDS     \"ca20 ca21 ca23 ca30 ca31 ca32 ca35 ca50 ca51 ca53 ca060 \\"
print -u$fd "                    ca40 ca45 ca47 ca48 ca49 ca4a ca4b ca4c ca80 ca90 ca91 ca96 ca97 \\"
print -u$fd "                    caa0 caa1 caa2 c021 c085 c086 c087 c088 c096 c04b c04e c04d\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/fmt"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}


#
# Prints sar icf
#

print_sar_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-mscid}
typeset bh=${6:-behind}
typeset sdir=${7:-smscriptsdir}
typeset ndays=${8:-2}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset rawdir=${11:-rawdir}
typeset rawnday=${12:-2}
typeset pastdays=${13:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    SRCUSER       Source login account username"
print -u$fd "#    SRCPSWD       Source login account password"
print -u$fd "#    SRCDIR        Remote source data directory"
print -u$fd "#    OMCRNAME      OMCR name"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    RAWDIRECTORY  Local directory for storing raw data files"
print -u$fd "#    RAWNDAYS      Number of days to keep raw data in RAWDIRECTORY"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#\n"
print -u$fd "set ICFBEHIND      \"$bh\""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set SRCUSER        \"$user\""
print -u$fd "set SRCPSWD        {$pswd}"
print -u$fd "set SRCDIR         \"$sdir\""
print -u$fd "set OMCRNAME       \"$srcid\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
if ([ "$rawdir" == "-1" ])
then
    print -u$fd "#set RAWDIRECTORY  \"/sc/spool/pmStats/PM/$NEID\""
else
    print -u$fd "set RAWDIRECTORY   \"$rawdir\""
fi
print -u$fd "set RAWNDAYS       \"$rawnday\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd ""
}

#
# Prints evdopm icf
#

print_evdopm_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-srcid}
typeset sdir=${6:-sdir}
typeset svrname=${7:-svrname}
typeset filedelay=${8:-5}
typeset cycle=${9:-10}
typeset bh=${10:-0}
typeset ndays=${11:-2}
typeset scurcol=${12:-1}
typeset scurdlvr=${13:-1}
typeset spooldir=${14:-1}
typeset spool=${15:-1}
typeset fodelay=${16:-1}
typeset foserver=${17:-1}
typeset redunip=${18:-redunip}
typeset redunuser=${19:-redunuser}
typeset redunpaswd=${20:-redunpaswd}
typeset redunsdir=${21:-redunsdir}
typeset pastdays=${22:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    SRCUSER       Source login account username"
print -u$fd "#    SRCPSWD       Source login account password"
print -u$fd "#    SRCDIR        Remote source data directory"
print -u$fd "#    SERVERNAME    OMC Server host name"
print -u$fd "#    OMCNAME       Unique OMC name across markets"
print -u$fd "#    FILEDELAY     Delay in minutes in file names"
print -u$fd "#    CYCLE         Data export cycle"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    SPOOLDIR	The directory where raw file is kept for SPOOLING"
print -u$fd "#    SPOOL		Can be on/off, on to turn  spooling on."
print -u$fd "#    FODELAY	The amount of delay in second of filename after failover occurs"
print -u$fd "#    FOSERVER	The servername after failover happen"
print -u$fd "#    REDUNIP       The redundant server IP address"
print -u$fd "#    REDUNUSER     The redundant server username"
print -u$fd "#    REDUNPASWD   The redundant server password"
print -u$fd "#    REDUNDIR      The redundant server source directory"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#\n"
print -u$fd "set ICFBEHIND      \"$bh\""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set SRCUSER        \"$user\""
print -u$fd "set SRCPSWD        {$pswd}"
print -u$fd "set SRCDIR         \"$sdir\""
print -u$fd "set SERVERNAME     \"$svrname\""
print -u$fd "set OMCNAME        \"$srcid\""
print -u$fd "set FILEDELAY      \"$filedelay\""
print -u$fd "set CYCLE          \"$cycle\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set SPOOLDIR       \"$spooldir\""
print -u$fd "set SPOOL          \"$spool\""
print -u$fd "set FODELAY        \"$fodelay\""
print -u$fd "set FOSERVER       \"$foserver\""
print -u$fd ""
print -u$fd "set REDUNIP        \"$redunip\""
print -u$fd "set REDUNUSER      \"$redunuser\""
print -u$fd "set REDUNPASWD     {$redunpaswd}"
print -u$fd "set REDUNDIR       \"$redunsdir\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}


#
# Prints evdopmemh icf
#

print_evdopmemh_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-srcid}
typeset sdir=${6:-sdir}
typeset svrname=${7:-svrname}
typeset filedelay=${8:-5}
typeset cycle=${9:-10}
typeset bh=${10:-0}
typeset ndays=${11:-2}
typeset scurcol=${12:-1}
typeset scurdlvr=${13:-1}
typeset spooldir=${14:-1}
typeset spool=${15:-1}
typeset pastdays=${16:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    SRCUSER       Source login account username"
print -u$fd "#    SRCPSWD       Source login account password"
print -u$fd "#    SRCDIR        Remote source data directory"
print -u$fd "#    SERVERNAME    OMC Server host name"
print -u$fd "#    EMHNAME       Unique EMH name across markets"
print -u$fd "#"
print -u$fd "#    FILEDELAY     Delay in minutes in file names"
print -u$fd "#    CYCLE         Data export cycle"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    SPOOLDIR	The directory where raw file is kept for SPOOLING"
print -u$fd "#    SPOOL		Can be on/off, on to turn  spooling on."
print -u$fd "#"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#\n"
print -u$fd "set ICFBEHIND      \"$bh\""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set SRCUSER        \"$user\""
print -u$fd "set SRCPSWD        {$pswd}"
print -u$fd "set SRCDIR         \"$sdir\""
print -u$fd "set SERVERNAME     \"$svrname\""
print -u$fd "set EMHNAME        \"$srcid\""
print -u$fd ""
print -u$fd "set FILEDELAY      \"$filedelay\""
print -u$fd "set CYCLE          \"$cycle\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set SPOOLDIR       \"$spooldir\""
print -u$fd "set SPOOL          \"$spool\""
print -u$fd ""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}

#
# EVDO CONFIG MAP
#
print_evdoconfig_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-srcid}
typeset sdir=${6:-sdir}
typeset svrname=${7:-svrname}
typeset bh=${8:-5}
typeset ndays=${9:-2}
typeset scurcol=${10:-1}
typeset scurdlvr=${11:-1}
typeset spooldir=${12:-1}
typeset spool=${13:-1}
typeset innerfiledir_f=${14:-0}


print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    SRCUSER       Source login account username"
print -u$fd "#    SRCPSWD       Source login account password"
print -u$fd "#    SRCDIR        Remote source data directory"
print -u$fd "#    SERVERNAME    OMC Server host name"
print -u$fd "#    OMCNAME       Unique OMC name across markets"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    SPOOLDIR      The directory where raw file is kept for SPOOLING"
print -u$fd "#    SPOOL         Can be on/off, on to turn  spooling on."
print -u$fd "#    INNERFILEDIR_F  Flag to collect config map from $SRCDIR/<date>/."
print -u$fd "#\n"
print -u$fd "set ICFBEHIND      \"$bh\""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set SRCUSER        \"$user\""
print -u$fd "set SRCPSWD        {$pswd}"
print -u$fd "set SRCDIR         \"$sdir\""
print -u$fd "set SERVERNAME     \"$svrname\""
print -u$fd "set OMCNAME        \"$srcid\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set SPOOLDIR       \"$spooldir\""
print -u$fd "set SPOOL          \"$spool\""
print -u$fd "set INNERFILEDIR_F   \"$innerfiledir_f\""
print -u$fd ""
}

#
# Prints evdocdl icf
#

print_evdocdl_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-srcid}
typeset sdir=${6:-sdir}
typeset svrname=${7:-svrname}
typeset filedelay=${8:-5}
typeset cycle=${9:-10}
typeset bh=${10:-0}
typeset ndays=${11:-2}
typeset scurcol=${12:-1}
typeset scurdlvr=${13:-1}
typeset spooldir=${14:-1}
typeset spool=${15:-1}
typeset fodelay=${16:-1}
typeset foserver=${17:-1}
typeset redunip=${18:-redunip}
typeset redunuser=${19:-redunuser}
typeset redunpaswd=${20:-redunpaswd}
typeset redunsdir=${21:-redunsdir}
typeset pastdays=${22:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    SRCUSER       Source login account username"
print -u$fd "#    SRCPSWD       Source login account password"
print -u$fd "#    SRCDIR        Remote source data directory"
print -u$fd "#    SERVERNAME    OMC Server host name"
print -u$fd "#    OMCNAME       Unique OMC name across markets"
print -u$fd "#    FILEDELAY     Delay in minutes in file names"
print -u$fd "#    CYCLE         Data export cycle"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    SPOOLDIR	The directory where raw file is kept for SPOOLING"
print -u$fd "#    SPOOL		Can be on/off, on to turn  spooling on."
print -u$fd "#    FODELAY	The amount of delay in second of filename after failover occurs"
print -u$fd "#    FOSERVER	The servername after failover happen"
print -u$fd "#"
print -u$fd "#    REDUNIP       The redundant server IP address"
print -u$fd "#    REDUNUSER     The redundant server username"
print -u$fd "#    REDUNPASWD   The redundant server password"
print -u$fd "#    REDUNDIR      The redundant server source directory"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#\n"
print -u$fd "set ICFBEHIND      \"$bh\""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set SRCUSER        \"$user\""
print -u$fd "set SRCPSWD        {$pswd}"
print -u$fd "set SRCDIR         \"$sdir\""
print -u$fd "set SERVERNAME     \"$svrname\""
print -u$fd "set OMCNAME        \"$srcid\""
print -u$fd "set FILEDELAY      \"$filedelay\""
print -u$fd "set CYCLE          \"$cycle\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set SPOOLDIR	\"$spooldir\""
print -u$fd "set SPOOL		\"$spool\""
print -u$fd "set FODELAY	\"$fodelay\""
print -u$fd "set FOSERVER	\"$foserver\""
print -u$fd ""
print -u$fd "set REDUNIP        \"$redunip\""
print -u$fd "set REDUNUSER      \"$redunuser\""
print -u$fd "set REDUNPASWD    {$redunpaswd}"
print -u$fd "set REDUNDIR       \"$redunsdir\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}
#
# Prints tmm icf
#

print_tmm_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-mscid}
typeset port=${6:-port}
typeset behind=${7:-behind}
typeset delay=${8:-delay}
typeset timeout=${9:-timeout}
typeset linkpair=${10:-linkpair}
typeset ch=${11:-ch}
typeset c0=${12:-c0}
typeset minbef=${13:-c0}
typeset minaft=${14:-c0}
typeset ignbef=${15:-c0}
typeset ignaft=${16:-c0}
typeset retry=${17:-retry}
typeset ndays=${18:-2}
typeset pastdays=${19:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    ICFBEHIND     Number of minutes to delay an interval"
print -u$fd "#    ICFDELAY      Number of seconds to delay between intervals"
print -u$fd "#    ICFMINBEF     Collect minimum data before this hour"
print -u$fd "#    ICFMINAFT     Collect minimum data after this hour"
print -u$fd "#    ICFIGNBEF     Don't collect data before this hour"
print -u$fd "#    ICFIGNAFT     Don't collect data after this hour"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    PORT          Port number to connect to MSC"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    TIMEOUT       Length of time to wait for tmm dump to complete"
print -u$fd "#    LINKPAIR      Link pair to use for dump (1 or 0)"
print -u$fd "#    CH            Trunks/Channels Flag (Y/N)"
print -u$fd "#    C0            C0 Flag (Y/N)"
print -u$fd "#    MSCID         MSC number of switch"
print -u$fd "#    MAXRETRIES    Switch connection retry count"
print -u$fd "#    LOCALDIR      Local directory for the collected data"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set ICFBEHIND      \"$behind\""
print -u$fd "set ICFDELAY       \"$delay\""
if ([ "$minbef" == "-1" ])
then
    print -u$fd "#set ICFMINBEF      \"06\""
else
    print -u$fd "set ICFMINBEF      \"$minbef\""
fi
if ([ "$minaft" == "-1" ])
then
    print -u$fd "#set ICFMINAFT      \"21\""
else
    print -u$fd "set ICFMINAFT      \"$minaft\""
fi
if ([ "$ignbef" == "-1" ])
then
    print -u$fd "#set ICFIGNBEF      \"06\""
else
    print -u$fd "set ICFIGNBEF      \"$ignbef\""
fi
if ([ "$ignaft" == "-1" ])
then
    print -u$fd "#set ICFIGNAFT      \"21\""
else
    print -u$fd "set ICFIGNAFT      \"$ignaft\""
fi
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set PORT           \"2076\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set TIMEOUT        \"$timeout\""
print -u$fd "set LINKPAIR       \"$linkpair\""
print -u$fd "set CH             \"$ch\""
print -u$fd "set C0             \"$c0\""
print -u$fd "set MSCID          \"$srcid\""
print -u$fd "set MSCNAME        \"$srcid\""
print -u$fd "set MAXRETRIES     \"$retry\""
print -u$fd ""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/fmt"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}


#
# Prints tmm cfg
#

print_tmm_cfg()
{
typeset fd=${1:-1}
typeset port=${2:-port}
typeset market=${3:-market}
typeset neid=${4:-neid}
typeset dtype=${5:-dtype}
typeset home=${6:-home}

print -u$fd "    Server              1"
print -u$fd "    LocalPort           $port"
print -u$fd "    ReceiveTimeout      -1"
print -u$fd "    ServerStoreFile     $home/log/$market.$neid.$dtype.store"
print -u$fd "    ServerRcvBuffer     65535"
print -u$fd "    ServerSndBuffer     4096"
print -u$fd "    ServerLogFile       /dev/null"
print -u$fd "    ServerLogLevel      0"
print -u$fd "    ServerLogFileSize   1024"
}


#
# Prints emx cfg icf
#

print_emxcfg_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-id}
typeset timeout=${6:-1680}
typeset retry=${7:-3}
typeset ndays=${8:-34}
typeset port=${9:-20}
typeset pastdays=${10:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote Terminal Server which connects the MSC host."
print -u$fd "#    PORT          Port number connects to MSC host from Terminal Server"
print -u$fd "#    USERNAME      User account name on remote Terminal Server"
print -u$fd "#    PASSWORD      User password on the remotem Terminal Server"
print -u$fd "#    EMXNAME       EMX(MSC) switch name"
print -u$fd "#    TIMEOUT       Number of seconds to wait for MMI command to complete"
print -u$fd "#    LOCALDIR      Local directory to put MSC CPU data files"
print -u$fd "#    DESTDIR       Local directory to put MSC CPU data files after sending to Prospect server"
print -u$fd "#    MAXRETRIES    Switch connection retry count"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set PORT           \"$port\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set EMXNAME        \"$srcid\""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set TIMEOUT        \"$timeout\""
print -u$fd "set MAXRETRIES     \"$retry\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}


#
# Prints emx cpu icf
#

print_emxcpu_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-id}
typeset timeout=${6:-1680}
typeset retry=${7:-3}
typeset ndays=${8:-34}
typeset port=${9:-20}
typeset rptint=${10:-20}
typeset pastdays=${11:-pastdays}

print -u$fd "#    ICFSNAP       Enable data collection in snapshot mode."
print -u$fd ""
print -u$fd "set ICFSNAP        \"1\""
print -u$fd ""

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote Terminal Server which connects the MSC host."
print -u$fd "#    PORT          Port number connects to MSC host from Terminal Server"
print -u$fd "#    USERNAME      User account name on remote Terminal Server"
print -u$fd "#    PASSWORD      User password on the remotem Terminal Server"
print -u$fd "#    EMXNAME       EMX(MSC) switch name"
print -u$fd "#    TIMEOUT       Number of seconds to wait for MMI command to complete"
print -u$fd "#    LOCALDIR      Local directory to put MSC CPU data files"
print -u$fd "#    DESTDIR       Local directory to put MSC CPU data files after sending to Prospect server"
print -u$fd "#    MAXRETRIES    Switch connection retry count"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set PORT           \"$port\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set EMXNAME        \"$srcid\""
print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set TIMEOUT        \"$timeout\""
print -u$fd "set MAXRETRIES     \"$retry\""
print -u$fd "set RPT_INTERVAL   \"$rptint\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}


#
# Prints omcr pm icf
#

print_omcrpm_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset pmdir=${5:-pmdir}
typeset omcrcfg=${6:-omcrcfg}
typeset mmid=$(echo ${7:-1}|tr "," " ")
typeset ndays=${8:-2}
typeset srcdir=${9:-srcdir}
typeset srcid=${10:-srcid}
typeset sduid=$(echo ${11:-1}|tr "," " ")
typeset sdurecs=$(echo ${12:-1}|tr "," " ")
typeset vpuid=$(echo ${13:-1}|tr "," " ")
typeset vpurecs=$(echo ${14:-1}|tr "," " ")
typeset anid=$(echo ${15:-1}|tr "," " ")
typeset anrecs=$(echo ${16:-1}|tr "," " ")
typeset svurecs=$(echo ${17:-1}|tr "," " ")
typeset pmcfgrecs=$(echo ${18:-1}|tr "," " ")
typeset rawdir=${19:-rawdir}
typeset rawnday=${20:-2}
typeset scurcol=${21:-1}
typeset scurdlvr=${22:-1}
typeset pastdays=${23:-pastdays}
typeset blockdir=${24:-blockdir}
typeset dbloadctrl=${25:-dbloadctrl}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTEPMDIR   PM data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    OMCRCFG       OMCR mapping file"
print -u$fd "#    MMID          CBSC IDs"
print -u$fd "#    SDUID         SDU IDs"
print -u$fd "#    SDURECORDS    SDU Record Numbers"
print -u$fd "#    VPUID         VPU IDs"
print -u$fd "#    VPURECORDS    VPU Record Numbers"
print -u$fd "#    ANID          AN IDs"
print -u$fd "#    ANRECORDS     AN Record Numbers"
print -u$fd "#    SVURECORDS    SVU Record Numbers"
print -u$fd "#    PMCFGRECORDS  PMCFG Record Numbers"
print -u$fd "#    SRCDIR        Local directory for the collected data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    RAWDIRECTORY  Local directory for storing raw data files"
print -u$fd "#    RAWNDAYS      Number of days to keep raw data in RAWDIRECTORY"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#    BLOCKDIR      DB loading control block directory"
print -u$fd "#    DBLOADCTRL    DB loading control block list file name"

print -u$fd ""
print -u$fd "set MMID           \"$mmid\""
if ([ "$sduid" == "-1" ])
then
    print -u$fd "#set SDUID         \"1 2\""
else
    print -u$fd "set SDUID          \"$sduid\""
fi
if ([ "$sdurecs" == "-1" ])
then
    print -u$fd "#set SDURECORDS    \"101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 203 206\""
else
    print -u$fd "set SDURECORDS     \"$sdurecs\""
fi
if ([ "$vpuid" == "-1" ])
then
    print -u$fd "#set VPUID         \"1 2\""
else
    print -u$fd "set VPUID          \"$vpuid\""
fi
if ([ "$vpurecs" == "-1" ])
then
    print -u$fd "#set VPURECORDS    \"140 141\""
else
    print -u$fd "set VPURECORDS     \"$vpurecs\""
fi
if ([ "$anid" == "-1" ])
then
    print -u$fd "#set ANID          \"1 2\""
else
    print -u$fd "set ANID           \"$anid\""
fi
if ([ "$anrecs" == "-1" ])
then
    print -u$fd "#set ANRECORDS     \"150 151\""
else
    print -u$fd "set ANRECORDS      \"$anrecs\""
fi
if ([ "$svurecs" == "-1" ])
then
    print -u$fd "#set SVURECORDS    \"160 161 162\""
else
    print -u$fd "set SVURECORDS     \"$svurecs\""
fi
if ([ "$pmcfgrecs" == "-1" ])
then
    print -u$fd "#set PMCFGRECORDS  \"80 85\""
else
    print -u$fd "set PMCFGRECORDS   \"$pmcfgrecs\""
fi

print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set REMOTEDIR      \"$srcdir\""
print -u$fd "set REMOTEPMDIR    \"$pmdir\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set OMCRCFG        \"$omcrcfg\""
print -u$fd "set OMCRNAME       \"$srcid\""
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
if ([ "$rawdir" == "-1" ])
then
    print -u$fd "#set RAWDIRECTORY  \"/sc/spool/pmStats/PM/$NEID\""
else
    print -u$fd "set RAWDIRECTORY   \"$rawdir\""
fi
print -u$fd "set RAWNDAYS       \"$rawnday\""
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd "set BLOCKDIR       \"$blockdir\""
print -u$fd "set DBLOADCTRL     \"$dbloadctrl\""

print -u$fd ""
}

#
# Prints anpm10min icf
#

print_anpm10min_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset srcid=${5:-srcid}
typeset sdir=${6:-sdir}
typeset pmdir=${7:-pmdir}
typeset omcrcfg=${8:-omcrcfg}
typeset svrname=${9:-svrname}
typeset ndays=${10:-2}
typeset scurcol=${11:-1}
typeset scurdlvr=${12:-1}
typeset rawdir=${13:-rawdir}
typeset rawnday=${14:-2}
typeset anid=$(echo ${15:-1}|tr "," " ")
typeset anrecs=$(echo ${16:-1}|tr "," " ")
typeset pastdays=${17:-pastdays}
typeset remotedir=${18:-remotedir}
typeset blockdir=${19:-blockdir}
typeset dbloadctrl=${20:-dbloadctrl}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    SRCIP         Source IP address"
print -u$fd "#    USERNAME      Source login account username"
print -u$fd "#    PASSWORD      Source login account password"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    SRCDIR 	      PM data directory on remote host"
print -u$fd "#    SERVERNAME    OMC Server host name"
print -u$fd "#    OMCRNAME      Unique OMC name across markets"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#"
print -u$fd "#    SRCDIR        Local directory for the collected data"
print -u$fd "#    RAWDIRECTORY  The directory where raw file is kept for SPOOLING"
print -u$fd "#    RAWNDAYS      Number of days to keep raw data in RAWDIRECTORY"
print -u$fd "#    ANID          AN IDs"
print -u$fd "#    ANRECORDS     AN Record Numbers"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#    BLOCKDIR      DB loading control block directory"
print -u$fd "#    DBLOADCTRL    DB loading control block list file name"
print -u$fd "#\n"
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set SRCIP          \"$ip\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set REMOTEDIR      \"$remotedir\""
print -u$fd "set SRCDIR		      \"$pmdir\""
print -u$fd "set SERVERNAME     \"$svrname\""
print -u$fd "set OMCRCFG        \"$omcrcfg\""
print -u$fd "set OMCRNAME       \"$srcid\""
print -u$fd ""
print -u$fd 'set SRCTMPDIR	"$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'

if ([ "$rawdir" == "-1" ])
then
    print -u$fd "#set RAWDIRECTORY  \"/sc/spool/pmStats/PM/$NEID\""
else
    print -u$fd "set RAWDIRECTORY   \"$rawdir\""
fi

print -u$fd "set RAWNDAYS       \"$rawnday\""
print -u$fd ""

if ([ "$anid" == "-1" ])
then
    print -u$fd "#set ANID          \"1 2\""
else
    print -u$fd "set ANID           \"$anid\""
fi

if ([ "$anrecs" == "-1" ])
then
    print -u$fd "#set ANRECORDS     \"150 151\""
else
    print -u$fd "set ANRECORDS      \"$anrecs\""
fi

print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd "set BLOCKDIR       \"$blockdir\""
print -u$fd "set DBLOADCTRL     \"$dbloadctrl\""

print -u$fd ""
}

#
# Prints PM Server PM icf
#

print_pmserver_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset pmdir=${5:-pmdir}
typeset ndays=${6:-2}
typeset srcdir=${7:-srcdir}
typeset srcid=${8:-srcid}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset pastdays=${11:-pastdays}
typeset blockdir=${12:-blockdir}
typeset dbloadctrl=${13:-dbloadctrl}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTEPMDIR   PM data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    PMSERVER      Name of the PM Server"
print -u$fd "#    SRCDIR        Local directory for the collected data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#    BLOCKDIR      DB loading control block directory"
print -u$fd "#    DBLOADCTRL    DB loading control block list file name"
print -u$fd ""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set REMOTEDIR      \"$srcdir\""
print -u$fd "set REMOTEPMDIR    \"$pmdir\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set PMSERVER       \"$srcid\""
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd "set BLOCKDIR       \"$blockdir\""
print -u$fd "set DBLOADCTRL     \"$dbloadctrl\""

print -u$fd "set NDAYS          \"$ndays\""
print -u$fd ""
}

#
# Prints PM Server AEMS C Tables icf
#

print_aemsc_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset pmdir=${5:-pmdir}
typeset ndays=${6:-2}
typeset srcdir=${7:-srcdir}
typeset srcid=${8:-srcid}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset pastdays=${11:-pastdays}
typeset blockdir=${12:-blockdir}
typeset dbloadctrl=${13:-dbloadctrl}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTEPMDIR   AEMS data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    PMSERVER      Name of the PM Server"
print -u$fd "#    SRCDIR        Local directory for the collected data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#    BLOCKDIR      DB loading control block directory"
print -u$fd "#    DBLOADCTRL    DB loading control block list file name"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd ""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set REMOTEDIR      \"$srcdir\""
print -u$fd "set REMOTEPMDIR    \"$pmdir\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set PMSERVER       \"$srcid\""
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd "set BLOCKDIR       \"$blockdir\""
print -u$fd "set DBLOADCTRL     \"$dbloadctrl\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd ""
}

#
# Prints omcr cdf icf
#

print_omcrcdf_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset cdfdir=${5:-cdfdir}
typeset srcdir=${6:-srcdir}
typeset omcrcfg=${7:-omcrcfg}
typeset ndays=${8:-2}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset pastdays=${11:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTECDFDIR  CDF data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    MAPPINGFILE   Mapping file for MSC name lookup"
print -u$fd "#    LOCALDIR      Destination directory for data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set REMOTEHOST       \"$ip\""
print -u$fd "set env(REMOTEHOST)  \"$ip\""
print -u$fd "set REMOTEDIR        \"$srcdir\""
print -u$fd "set REMOTECDFDIR     \"$cdfdir\""
print -u$fd "set USERNAME         \"$user\""
print -u$fd "set PASSWORD         {$pswd}"
print -u$fd "set env(MAPPINGFILE) \"$omcrcfg\""
print -u$fd 'set LOCALDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set env(LOCALDIR)    "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR          "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd 'set env(DESTDIR)     "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set SECURECOLLECT    \"$scurcol\""
print -u$fd "set SECUREDELIVER    \"$scurdlvr\""
print -u$fd "set NDAYS            \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}

#
# Prints omcr necf icf
#

print_omcrnecf_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset necfdir=${5:-necfdir}
typeset srcdir=${6:-srcdir}
typeset omcrcfg=${7:-omcrcfg}
typeset ndays=${8:-2}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset srcid=${11:-srcid}
typeset pastdays=${12:-pastdays}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTENECFDIR NECF data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    MAPPINGFILE   Mapping file for MSC name lookup"
print -u$fd "#    OMCRCFG       OMCR mapping configuration file"
print -u$fd "#    OMCRNAME      OMCR name"
print -u$fd "#    LOCALDIR      Destination directory for data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set REMOTEHOST       \"$ip\""
print -u$fd "set env(REMOTEHOST)  \"$ip\""
print -u$fd "set REMOTEDIR        \"$srcdir\""
print -u$fd "set REMOTENECFDIR    \"$necfdir\""
print -u$fd "set USERNAME         \"$user\""
print -u$fd "set PASSWORD         {$pswd}"
print -u$fd "set env(MAPPINGFILE) \"$omcrcfg\""
print -u$fd "set OMCRCFG          \"$omcrcfg\""
print -u$fd "set OMCRNAME         \"$srcid\""
print -u$fd 'set LOCALDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set env(LOCALDIR)    "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR          "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd 'set env(DESTDIR)     "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set SECURECOLLECT    \"$scurcol\""
print -u$fd "set SECUREDELIVER    \"$scurdlvr\""
print -u$fd "set NDAYS            \"$ndays\""
print -u$fd "set PAST_DAYS        \"$pastdays\""
print -u$fd ""
}

#
# Prints omcr cdl cfg
#

print_omcrcdl_cfg()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset port=${5:-port}
typeset omcrcfg=${6:-omcrcfg}
typeset ndays=${7:-34}
typeset market=${8:-market}
typeset neid=${9:-omcr}
typeset netype=${10:-CDL}
typeset flexdahome=${11:-/u/flexda}
typeset sleep=${12:-60}
typeset delaygap=${13:-60}

print -u$fd "#"
print -u$fd "# CDL config file"
print -u$fd "#"
print -u$fd "#    OMCRHOST      Address of remote host"
print -u$fd "#    SRCDIR        Local directory for data files"
print -u$fd "#    LOGDIR        Local directory for log files"
print -u$fd "#    PORT          Port number"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    ICFLOGFILE    Check point file"
print -u$fd "#    MAPPINGFILE   Mapping file for MSC name lookup"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    SLEEPSECONDS  Number of seconds to wait between retries"
print -u$fd ""
print -u$fd "OMCRHOST       $ip"
print -u$fd "SRCDIR         $flexdahome/data/$market/$neid/$netype/src"
print -u$fd "LOGDIR         $flexdahome/log/$market"
print -u$fd "PORT           $port"
print -u$fd "DESTDIR        $flexdahome/data/$market/$neid/$netype/dest"
print -u$fd "ICFLOGFILE     $flexdahome/log/$market.$neid.$netype.chk"
print -u$fd "MAPPINGFILE    $omcrcfg"
print -u$fd "USERNAME       $user"
print -u$fd "PASSWORD       $pswd"
print -u$fd "NDAYS          $ndays"
print -u$fd "SLEEPSECONDS   $sleep"
print -u$fd "ICFDELAYGAP    $delaygap"
print -u$fd ""
}

#
# Prints kci cfg icf
#

print_kcicfg_icf()
{
typeset fd=${1:-1}
typeset tdir=${2:-tdir}
typeset ip=${3:-ip}
typeset id=${4:-id}
typeset user=${5:-user}
typeset pswd=${6:-pswd}
typeset srcdir=${7:-srcdir}
typeset cfgname=${8:-cfgname}
typeset spool=${9:-on}
typeset spooldir=${10:-spooldir}
typeset collminute=${11:-00}
typeset collhour=${12:-04}
typeset ndays=${13:-3}
typeset scurcol=${14:-1}
typeset scurdlvr=${15:-1}
typeset pastdays=${16:-pastdays}


print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    TGTDIR        Target directory of the Prospect server"
print -u$fd "#    SRCIP         IP of the remote source host"
print -u$fd "#    SRCID         ID of the remote source host"
print -u$fd "#    SRCUSER       User account name on the remote source host"
print -u$fd "#    SRCPSWD       User password on the the remote source host"
print -u$fd "#    SRCDIR        Directory of the remote source host"
print -u$fd "#    CFGNAME       Configuration Data File prefix"
print -u$fd "#    SPOOL         Can be on/off, on to turn  spooling on."
print -u$fd "#    SPOOLDIR      Local spool directory"
print -u$fd "#    LOCALDIR      Destination directory for data"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    COLLMINUTE    Time (in minutes) to collect the data from the remote host"
print -u$fd "#    COLLHOUR      Time (in hours) to collect the data from the remote host"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd ""
print -u$fd "set TGTDIR        \"$tdir\""
print -u$fd "set SRCIP         \"$ip\""
print -u$fd "set SRCID         \"$id\""
print -u$fd "set SRCUSER       \"$user\""
print -u$fd "set SRCPSWD       {$pswd}"
print -u$fd "set SRCDIR        \"$srcdir\""
print -u$fd "set CFGNAME       \"$cfgname\""
print -u$fd "set SPOOL         \"$spool\""
print -u$fd "set SPOOLDIR      \"$spooldir\""
print -u$fd 'set LOCALDIR      "$env(FLEXDAHOME)/data/$MARKET/$NEID/$NETYPE"'
print -u$fd "set COLLMINUTE    \"$collminute\""
print -u$fd "set COLLHOUR      \"$collhour\""
print -u$fd "set SECURECOLLECT \"$scurcol\""
print -u$fd "set SECUREDELIVER \"$scurdlvr\""
print -u$fd "set NDAYS         \"$ndays\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd ""
}

#
# Prints AEMS C 10 minutes Tables icf
#

print_aemsc10min_icf()
{
typeset fd=${1:-1}
typeset ip=${2:-ip}
typeset user=${3:-user}
typeset pswd=${4:-pswd}
typeset pmdir=${5:-pmdir}
typeset ndays=${6:-2}
typeset srcdir=${7:-srcdir}
typeset srcid=${8:-srcid}
typeset scurcol=${9:-1}
typeset scurdlvr=${10:-1}
typeset pastdays=${11:-pastdays}
typeset blockdir=${12:-blockdir}
typeset dbloadctrl=${13:-dbloadctrl}

print -u$fd "#"
print -u$fd "# Application Variables:"
print -u$fd "#"
print -u$fd "#    REMOTEHOST    Address of remote host"
print -u$fd "#    REMOTEDIR     Directory of remote host to place created tar file"
print -u$fd "#    REMOTEPMDIR   AEMS data directory on remote host"
print -u$fd "#    USERNAME      User account name on remote host"
print -u$fd "#    PASSWORD      User password on the remote host"
print -u$fd "#    PMSERVER      Name of the PM Server"
print -u$fd "#    SRCDIR        Local directory for the collected data"
print -u$fd "#    DESTDIR       Local directory for the collected data after sent to Prospect"
print -u$fd "#    SECURECOLLECT Whether to use SCP/SSH to collect data"
print -u$fd "#    SECUREDELIVER Whether to use SCP to deliver files to Prospect"
print -u$fd "#    PAST_DAYS     Number of days to start collecting data file"
print -u$fd "#    BLOCKDIR      DB loading control block directory"
print -u$fd "#    DBLOADCTRL    DB loading control block list file name"
print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
print -u$fd ""
print -u$fd "set REMOTEHOST     \"$ip\""
print -u$fd "set REMOTEDIR      \"$srcdir\""
print -u$fd "set REMOTEPMDIR    \"$pmdir\""
print -u$fd "set USERNAME       \"$user\""
print -u$fd "set PASSWORD       {$pswd}"
print -u$fd "set PMSERVER       \"$srcid\""
print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/src"'
print -u$fd 'set DESTDIR        "$env(FLEXDAHOME)/data/${MARKET}/${NEID}/${NETYPE}/dest"'
print -u$fd "set SECURECOLLECT  \"$scurcol\""
print -u$fd "set SECUREDELIVER  \"$scurdlvr\""
print -u$fd "set PAST_DAYS      \"$pastdays\""
print -u$fd "set BLOCKDIR       \"$blockdir\""
print -u$fd "set DBLOADCTRL     \"$dbloadctrl\""
print -u$fd "set NDAYS          \"$ndays\""
print -u$fd ""
}

#
# Creates Motorola monitor config file
#

print_Motorola_mon()
{
typeset    fd=${1:-1}
typeset    optname=${2:-option_name}
typeset -u sysname=${3:-hostname}
typeset    m_detail

for opt in ${optname[*]}
do
    typeset -u grpname="$grpname MT${opt}"
done

typeset i=0
typeset n=0
while (($n < ${#d_market[*]}))
do
    found=0
    for opt in ${optname[*]}
    do
        echo ${d_mtopts[$n]} | tr "," " " | grep ${opt} >/dev/null
        if [ $? -eq 0 ]
        then
            typeset -u m_optname[$i]="MT${opt}"
            found=1
            break
        fi
    done

    if [[ $found -eq 0 ]]
    then
        ((n=n+1))
        continue
    fi

    typeset m_mktid[$i]=${d_market[$n]}
    typeset m_ip[$i]=${d_srcip[$n]}
    typeset m_id[$i]=${d_srcid[$n]}
    typeset m_port[$i]=${d_port[$n]}
    typeset m_dtypes[$i]=${d_mtopts[$n]}
    typeset m_type[$i]=${d_type[$n]}
    typeset m_version[$i]=${d_version[$n]}
    typeset eval ${m_optname[$i]}[$i]=${m_id[$i]}

    ((i=i+1))
    ((n=n+1))
done

print -u$fd "!"
print -u$fd "! MOTOROLA DA MONITOR SCRIPT"
print -u$fd "!"
print -u$fd ""
print -u$fd "system.name:			${sysname}"
print -u$fd ""
print -u$fd "${sysname}.groups:			${grpname[*]}"

for opt in ${grpname[*]}
do
    case $opt in
        MTTMM )   mon_proc="READER PARSER"
                    typeset grpid=${MTTMM[*]}
                    ;;

        MTCDL )  mon_proc="READER"
                    typeset grpid=${MTCDL[*]}
                    ;;
    esac

    print -u$fd "${sysname}.${opt}.groups:		${grpid}"
    for id in ${grpid}
    do
        print -u$fd "*${opt}.${id}.processes:	${mon_proc[*]}"
    done
    print -u$fd ""
done

print -u$fd ""
print -u$fd "!"
print -u$fd "! Global Defaults"
print -u$fd "!"
print -u$fd ""
print -u$fd "*wait:             10"
print -u$fd "*retry:            5"
print -u$fd "*timeout:          30"
print -u$fd "*delay:            10"
print -u$fd "*normal:           false"
print -u$fd ""
print -u$fd "!"
print -u$fd "! Start the threads in reverse order so that later stages will be ready and"
print -u$fd "! waiting for earlier stages."
print -u$fd "!"
print -u$fd ""
print -u$fd "*READER.start:    		2"
print -u$fd "*PARSER.start:    		1"
print -u$fd ""
print -u$fd "*READER.down:    		2"
print -u$fd "*PARSER.down:    		1"
print -u$fd ""
print -u$fd "!"
print -u$fd "! Allow infinite retries for all readers."
print -u$fd "!"
print -u$fd ""
print -u$fd "*READER.retry:    		-1"
print -u$fd ""

typeset d=0
while (($d < ${#m_id[*]}))
do
    typeset    d_type="${m_type[$d]}"
    typeset    d_optname="${m_optname[$d]}"

    if [ $d_optname == "MTTMM" ]
    then
        typeset -l b_dir="${m_mktid[$d]}_${d_type}${m_id[$d]}"
        typeset    datatype="TMM"
        print -u$fd "!"
        print -u$fd "! $d_optname ${m_id[$d]}"
        print -u$fd "!"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.program: mp_emis_reader"
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.argv: \\"
        print -u$fd "    -L log/${m_mktid[$d]},${m_mktid[$d]}.${m_id[$d]}.mp_emis.,.log,1440,100000,7 \\"
        print -u$fd "    cfg/${m_mktid[$d]}.${m_id[$d]}.${datatype}.cfg \\"
        print -u$fd "    data/${m_mktid[$d]}/${m_id[$d]}/${datatype}/src,${m_id[$d]}.,.TMM,30,1048576,10"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.program: tmm_file"
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.argv: \\"
        print -u$fd "    -v ${m_version[$d]} \\"
        print -u$fd "    -L log/${m_mktid[$d]},${m_mktid[$d]}.${m_id[$d]}.tmm_file.,.log,1440,100000,7 \\"
        print -u$fd "    cfg/${m_mktid[$d]}.${m_id[$d]}.${datatype}.icf \\"
        print -u$fd "    data/${m_mktid[$d]}/${m_id[$d]}/$datatype/src \\"
        print -u$fd "    data/${m_mktid[$d]}/${m_id[$d]}/$datatype/fmt \\"
        print -u$fd "    ${m_id[$d]}"
        print -u$fd ""
    elif [ $d_optname == "MTCDL" ]
    then
        typeset -l b_dir="${m_mktid[$d]}_${d_type}${m_id[$d]}"
        typeset    datatype="CDL"
        print -u$fd "!"
        print -u$fd "! ${d_optname} ${m_id[$d]}"
        print -u$fd "!"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.program: fetch_cdl.pl"
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.argv: \\"
        print -u$fd "    cfg/${m_mktid[$d]}.${m_id[$d]}.${datatype}.cfg"
        print -u$fd ""
    fi

    ((d=d+1))
done

}

# checkdup()
# {
#  typeset array=$1
#  typeset tocheck=$2
#  typeset optname=$3
#  typeset found=0
#  typeset flag=0
#  typeset -l answer
#  for ii in ${array[*]}
#  do
#      if [ $ii = $tocheck ]
#      then
#        found=1
#        break
#      fi
#  done
#  if [ $found -eq 1 ]
#  then
#     read answer?"${optname}:$2 is duplicated continue?[y|n]"
#     case $answer in
#      n|no)  exit;;
#      y|yes) flag=0;;
#     esac
#     return $flag
#  fi
#  return 0
# }


#
# Validates configuration file and populate array
#

check_cfg_file()
{
typeset cfg=${1}
typeset tmpcfg=/tmp/da.cfg.$$
typeset tmplog=/tmp/da.err.$$

if [ ! -f $cfg ]
then
    echo "${cmd}: Configuration file $cfg not found"
    exit 1
fi

# Remove invalid data in the configuration file
cat $cfg | sed 's/\\ *$/\\/' | sed 's/ *= */=/g' | sed 's/ *, */,/g' | \
    sed '/^$/d' > $tmpcfg
#cat $cfg | sed -e 's/\\ *$/\\/' -e 's/ *= */=/g' -e 's/ *, */,/g' \
#  -e '/^$/d' > $tmpcfg

# Source configuration file and check for error
. $tmpcfg 2>&1 2>/$tmplog

if [ -s $tmplog ]
then
    echo "${cmd}: Error reading configuration file: $cfg"
    exit 1;
fi

# Remove temporary files
rm -f $tmpcfg $tmplog

# Ensure that the correct number of attributes (na) have been specified
# for lhost thost Motorola
typeset na_lhost=2
typeset na_thost=4
typeset na_ntcdma=1

if ( [ `expr ${#lhost[*]} % $na_lhost` != 0 ] || \
     [ `expr ${#thost[*]} % $na_thost` != 0 ] )
then
    echo "${cmd}: Incorrect number of arguments for lhost, thost"
    echo "${cmd}: check the arguments for lhost or thost in $1"
    exit 1
fi

typeset j=0
typeset i=0
while (($j < ${#mtcdma_type[*]}))
do
    # Get detailed information for each mtcdma type
    set -A detail $(eval echo \${mtcdma_${mtcdma_type[$j]}[*]})

    case ${mtcdma_type[$j]} in
        omcr )       na_detail=31;;
        msc )        na_detail=23;;
        sm )         na_detail=17;;
        sar )        na_detail=13;;
        evdopm )     na_detail=22;;
        evdopmemh )  na_detail=16;;
        evdocdl )    na_detail=22;;
	evdoconfigmap )  na_detail=14;;
        anpm10min )  na_detail=20;;
        pmserver )   na_detail=15;;
        kcicfg )     na_detail=16;;
        aemsc10min ) na_detail=15;;
        *)  echo "${cmd}: Invalid option name $c_optname"; exit 1;;
    esac

    if ([ ${#detail[*]} == 0 ] || [ `expr ${#detail[*]} % $na_detail` != 0 ])
    then
        echo "${cmd}: mtcdma_${mtcdma_type[$j]} not specified properly"
        ((j=j+1))
        continue
    fi

    # Get mtcdma type detailed info
    typeset k=0
#     typeset trc=0
#     typeset trid=0
#     typeset configuration=1
#     unset d_ipdup  d_iddup
    while (($k < ${#detail[*]}))
    do
        unset d_market[$i] d_tdir[$i] d_srcip[$i] d_srcid[$i]
        unset d_mmid[$i] d_srcuser[$i] d_srcpswd[$i] d_srcdir[$i]
        unset d_cdfdir[$i] d_pmdir[$i] d_omcrcfg[$i] d_cdlsleep[$i]
        unset d_mtopts[$i] d_type[$i] d_tmadj[$i] d_delaygap[$i]
        unset d_port[$i] d_timeout[$i] d_linkpair[$i] d_emisport[$i]
        unset d_ch[$i] d_c0[$i] d_maxretry[$i] d_behind[$i] d_delay[$i]
        unset d_minbef[$i] d_minaft[$i] d_ignbef[$i] d_ignaft[$i]
        unset d_rptint[$i] d_version[$i]
	    unset d_sduid[$i] d_sdurecs[$i] d_vpuid[$i] d_vpurecs[$i]
        unset d_swid[$i]  d_smrepddcfg[$i] d_smscriptsdir[$i]
	    unset d_anid[$i] d_anrecs[$i]
	    unset d_svrname[$i] d_filedelay[$i] d_cycle[$i]
	    unset d_rawdir[$i] d_rawnday[$i] d_scol[$i] d_sdel[$i]
	    unset d_spooldir[$i]  d_spool[$i]  d_fodelay[$i] d_foserver[$i]
	    unset d_collminute[$i] d_collhour[$i] d_mscname[$i]
        unset d_remotedir[$i] d_innerfiledir_f[$i]
        unset d_securecollect[$i] d_securedeliver[i]
        unset d_blockdir[$i] d_dbloadctrl[$i]

        case ${mtcdma_type[$j]} in
        omcr )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_mmid[$i]=${detail[$k]};     ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_cdfdir[$i]=${detail[$k]};   ((k=k+1))
            d_pmdir[$i]=${detail[$k]};    ((k=k+1))
            d_omcrcfg[$i]=${detail[$k]};  ((k=k+1))
            d_srcdir[$i]=${detail[$k]};   ((k=k+1))
            d_port[$i]=${detail[$k]};     ((k=k+1))
            d_mtopts[$i]=${detail[$k]};   ((k=k+1))
            d_tmadj[$i]=${detail[$k]};    ((k=k+1))
            d_cdlsleep[$i]=${detail[$k]}; ((k=k+1))
            d_delaygap[$i]=${detail[$k]}; ((k=k+1))
            d_sduid[$i]=${detail[$k]};    ((k=k+1))
            d_sdurecs[$i]=${detail[$k]};  ((k=k+1))
            d_vpuid[$i]=${detail[$k]};    ((k=k+1))
            d_vpurecs[$i]=${detail[$k]};  ((k=k+1))
            d_anid[$i]=${detail[$k]};     ((k=k+1))
            d_anrecs[$i]=${detail[$k]};   ((k=k+1))
            d_svurecs[$i]=${detail[$k]};  ((k=k+1))
            d_pmcfgrecs[$i]=${detail[$k]};((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_rawdir[$i]=${detail[$k]};   ((k=k+1))
            d_rawnday[$i]=${detail[$k]};  ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_blockdir[$i]=${detail[$k]}; ((k=k+1))
            d_dbloadctrl[$i]=${detail[$k]}; ((k=k+1))
            d_type[$i]=${mtcdma_type[$j]}
            ;;

        msc )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_port[$i]=${detail[$k]};     ((k=k+1))
            d_timeout[$i]=${detail[$k]};  ((k=k+1))
            d_linkpair[$i]=${detail[$k]}; ((k=k+1))
            d_ch[$i]=${detail[$k]};       ((k=k+1))
            d_c0[$i]=${detail[$k]};       ((k=k+1))
            d_maxretry[$i]=${detail[$k]}; ((k=k+1))
            d_emisport[$i]=${detail[$k]}; ((k=k+1))
            d_mtopts[$i]=${detail[$k]};   ((k=k+1))
            d_rptint[$i]=${detail[$k]};   ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_delay[$i]=${detail[$k]};    ((k=k+1))
            d_minbef[$i]=${detail[$k]};   ((k=k+1))
            d_minaft[$i]=${detail[$k]};   ((k=k+1))
            d_ignbef[$i]=${detail[$k]};   ((k=k+1))
            d_ignaft[$i]=${detail[$k]};   ((k=k+1))
            d_version[$i]=${detail[$k]};  ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_type[$i]=${mtcdma_type[$j]}
            ;;

        sm )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_swid[$i]=${detail[$k]};     ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_timeout[$i]=${detail[$k]};  ((k=k+1))
            d_mtopts[$i]=${detail[$k]};   ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_delay[$i]=${detail[$k]};    ((k=k+1))
            d_ignbef[$i]=${detail[$k]};   ((k=k+1))
            d_ignaft[$i]=${detail[$k]};   ((k=k+1))
            d_version[$i]=${detail[$k]};  ((k=k+1))
            d_smrepddcfg[$i]=${detail[$k]};  ((k=k+1))
            d_smscriptsdir[$i]=${detail[$k]};  ((k=k+1))
            d_pastdays[$i]=${detail[$k]};     ((k=k+1))
            d_type[$i]=${mtcdma_type[$j]}
            ;;

        sar )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_sdir[$i]=${detail[$k]};     ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_rawdir[$i]=${detail[$k]};   ((k=k+1))
            d_rawnday[$i]=${detail[$k]};  ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_mtopts[$i]=SAR;
            ;;

        evdopm )
            d_market[$i]=${detail[$k]};     ((k=k+1))
            d_tdir[$i]=${detail[$k]};       ((k=k+1))
            d_srcip[$i]=${detail[$k]};      ((k=k+1))
            d_srcid[$i]=${detail[$k]};      ((k=k+1))
            d_srcuser[$i]=${detail[$k]};    ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};    ((k=k+1))
            d_sdir[$i]=${detail[$k]};       ((k=k+1))
            d_svrname[$i]=${detail[$k]};    ((k=k+1))
            d_filedelay[$i]=${detail[$k]};  ((k=k+1))
            d_cycle[$i]=${detail[$k]};      ((k=k+1))
            d_behind[$i]=${detail[$k]};     ((k=k+1))
            d_scol[$i]=${detail[$k]};       ((k=k+1))
            d_sdel[$i]=${detail[$k]};       ((k=k+1))
	        d_spooldir[$i]=${detail[$k]};   ((k=k+1))
	        d_spool[$i]=${detail[$k]};      ((k=k+1))
	        d_fodelay[$i]=${detail[$k]};    ((k=k+1))
	        d_foserver[$i]=${detail[$k]};   ((k=k+1))
   	    	d_redunip[$i]=${detail[$k]};    ((k=k+1))
	    	d_redunuser[$i]=${detail[$k]};  ((k=k+1))
	    	d_redunpaswd[$i]=${detail[$k]}; ((k=k+1))
	    	d_redundir[$i]=${detail[$k]};   ((k=k+1))
	    	d_pastdays[$i]=${detail[$k]};   ((k=k+1))
            d_mtopts[$i]=EVDOPM;
            ;;

        evdopmemh )
            d_market[$i]=${detail[$k]};     ((k=k+1))
            d_tdir[$i]=${detail[$k]};       ((k=k+1))
            d_srcip[$i]=${detail[$k]};      ((k=k+1))
            d_srcid[$i]=${detail[$k]};      ((k=k+1))
            d_srcuser[$i]=${detail[$k]};    ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};    ((k=k+1))
            d_sdir[$i]=${detail[$k]};       ((k=k+1))
            d_svrname[$i]=${detail[$k]};    ((k=k+1))
            d_filedelay[$i]=${detail[$k]};  ((k=k+1))
            d_cycle[$i]=${detail[$k]};      ((k=k+1))
            d_behind[$i]=${detail[$k]};     ((k=k+1))
            d_scol[$i]=${detail[$k]};       ((k=k+1))
            d_sdel[$i]=${detail[$k]};       ((k=k+1))
	        d_spooldir[$i]=${detail[$k]};   ((k=k+1))
	        d_spool[$i]=${detail[$k]};      ((k=k+1))
	    	d_pastdays[$i]=${detail[$k]};   ((k=k+1))
            d_mtopts[$i]=EVDOPMEMH;
            ;;

        evdocdl )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_sdir[$i]=${detail[$k]};     ((k=k+1))
            d_svrname[$i]=${detail[$k]};  ((k=k+1))
            d_filedelay[$i]=${detail[$k]};  ((k=k+1))
            d_cycle[$i]=${detail[$k]};    ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
	        d_spooldir[$i]=${detail[$k]};     ((k=k+1))
	        d_spool[$i]=${detail[$k]};     ((k=k+1))
	        d_fodelay[$i]=${detail[$k]};     ((k=k+1))
	        d_foserver[$i]=${detail[$k]};     ((k=k+1))
	    	d_redunip[$i]=${detail[$k]};     ((k=k+1))
            d_redunuser[$i]=${detail[$k]};     ((k=k+1))
            d_redunpaswd[$i]=${detail[$k]};     ((k=k+1))
            d_redundir[$i]=${detail[$k]};     ((k=k+1))
	    	d_pastdays[$i]=${detail[$k]};     ((k=k+1))
            d_mtopts[$i]=EVDOCDL;
            ;;

        evdoconfigmap )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
             d_sdir[$i]=${detail[$k]};     ((k=k+1))
             d_svrname[$i]=${detail[$k]};  ((k=k+1))
               d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_spooldir[$i]=${detail[$k]};     ((k=k+1))
            d_spool[$i]=${detail[$k]};     ((k=k+1))
            d_innerfiledir_f[$i]=${detail[$k]};     ((k=k+1))
            d_mtopts[$i]=EVDOCONFIGMAP;
            ;;

        anpm10min )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_pmdir[$i]=${detail[$k]};    ((k=k+1))
            d_omcrcfg[$i]=${detail[$k]};  ((k=k+1))
            d_sdir[$i]=${detail[$k]};     ((k=k+1))
            d_svrname[$i]=${detail[$k]};  ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
	        d_rawdir[$i]=${detail[$k]};   ((k=k+1))
	        d_rawnday[$i]=${detail[$k]};  ((k=k+1))
            d_anid[$i]=${detail[$k]};     ((k=k+1))
            d_anrecs[$i]=${detail[$k]};   ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_remotedir[$i]=${detail[$k]}; ((k=k+1))
            d_blockdir[$i]=${detail[$k]}; ((k=k+1))
            d_dbloadctrl[$i]=${detail[$k]}; ((k=k+1))
            d_mtopts[$i]=ANPM10MIN;
            ;;

        pmserver )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_pmdir[$i]=${detail[$k]};    ((k=k+1))
            d_srcdir[$i]=${detail[$k]};   ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_mtopts[$i]=${detail[$k]};   ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_blockdir[$i]=${detail[$k]}; ((k=k+1))
            d_dbloadctrl[$i]=${detail[$k]}; ((k=k+1))
            ;;

        kcicfg )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_srcdir[$i]=${detail[$k]};   ((k=k+1))
            d_cfgname[$i]=${detail[$k]};  ((k=k+1))
            d_spool[$i]=${detail[$k]};    ((k=k+1))
            d_spooldir[$i]=${detail[$k]}; ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_collminute[$i]=${detail[$k]}; ((k=k+1))
            d_collhour[$i]=${detail[$k]}; ((k=k+1))
            d_rawnday[$i]=${detail[$k]};  ((k=k+1))
            d_pastdays[$i]=${detail[$k]};  ((k=k+1))
            d_mtopts[$i]=KCICFG;
            ;;

        aemsc10min )
            d_market[$i]=${detail[$k]};   ((k=k+1))
            d_tdir[$i]=${detail[$k]};     ((k=k+1))
            d_srcip[$i]=${detail[$k]};    ((k=k+1))
            d_srcid[$i]=${detail[$k]};    ((k=k+1))
            d_srcuser[$i]=${detail[$k]};  ((k=k+1))
            d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
            d_pmdir[$i]=${detail[$k]};    ((k=k+1))
            d_srcdir[$i]=${detail[$k]};   ((k=k+1))
            d_behind[$i]=${detail[$k]};   ((k=k+1))
            d_mtopts[$i]=${detail[$k]};   ((k=k+1))
            d_scol[$i]=${detail[$k]};     ((k=k+1))
            d_sdel[$i]=${detail[$k]};     ((k=k+1))
            d_pastdays[$i]=${detail[$k]}; ((k=k+1))
            d_blockdir[$i]=${detail[$k]}; ((k=k+1))
            d_dbloadctrl[$i]=${detail[$k]}; ((k=k+1))
            ;;

        * ) echo "{$cmd}: ${mtcdma_type[$j]} is not valid Motorola type"
            exit 1
            ;;
        esac

        ((i=i+1))
    done

((j=j+1))
done
}

################################################################################
#                                                                              #
#                                Main Script                                   #
#                                                                              #
################################################################################

cmd=`basename $0`

test $# != 1 && usage

# Check the environment variable
if ([ -z $FLEXDAHOME ] || [ ! -d $FLEXDAHOME ])
then
    echo "${cmd}: FLEXDAHOME directory not found"
    exit 1
fi

cfgfile=$1

# cfg directory
CFGDIR=$FLEXDAHOME/cfg

# log directory
LOGDIR=$FLEXDAHOME/log

# data directory
DATADIR=$FLEXDAHOME/data

# backup directory
dtfmt=`date +$(echo :Y:m:d:H:M | tr ":" "%")`
SAVEDIR=$FLEXDAHOME/cfg/backup/mtcdma_$dtfmt


#  Each Motorola process common info
# MTPROCS   VDR DSVR NETYPE   DTYPE      PRD(M) ENTRY RETRY CRONTM             DIR       MON?
# -------   --- ---- ------   -----      ------ ----- ----- ------             -----     ----
set -A  MTPROCS                                                                \
  SMTM       mt  ""   sm       smtm       30     336   3     "5,35"             "src|fmt|dest"          N \
  TMM        mt  ""   msc      tmm        30     336   3     "5,35"             "src|src/save|fmt|dest" Y \
  CFG        mt  ""   msc      motcfgdist 1440   336   3     "5|0,1,2"          "src|dest"              N \
  CPU        mt  ""   msc      motcpudist 1440   336   0     "0,30"             "src|dest"              N \
  PM         mt  ""   omcr     pm         30     336   3     "20,50"            "src|dest"              N \
  PMCFG      mt  ""   omcr     pmcfg      30     336   3     "20,50"            "src|dest"              N \
  ANPM10MIN  mt  ""   omcr     anpm10min  10     336   3     "0,10,20,30,40,50" "src|dest"              N \
  PMSERVER   mt  ""   pmserver pmserver   30     336   3     "20,50"            "src|dest"              N \
  AEMSC13    mt  ""   pmserver aemsc13    30     1000  3     "20,50"            "src|dest"              N \
  AEMSC2     mt  ""   pmserver aemsc2     10     1000  3     "0,10,20,30,40,50" "src|dest"              N \
  AEMSC4     mt  ""   pmserver aemsc4     30     1000  3     "8,38"             "src|dest"              N \
  CDF        mt  ""   omcr     cdf        1440   1000  3     "10|0,1,2"         "src|dest"              N \
  NECF       mt  ""   omcr     necf       1440   1000  3     "10|0,1,2"         "src|dest"              N \
  CDL        mt  ""   omcr     CDL        10     1008  3     "|"                "src|dest"              Y \
  SAR        mt  ""   omcr     sar        10     1008  3     "5,15,25,35,45,55" ""                      N \
  EVDOPM     mt  ""   evdo     evdopm     10     1008  3     "0,10,20,30,40,50" ""                      N \
  EVDOPMEMH  mt  ""   evdo     evdopmemh  10     1008  3     "0,10,20,30,40,50" "src|dest"              N \
  EVDOCDL    mt  ""   evdo     evdocdl    10     1008  3     "0,10,20,30,40,50" ""                      N \
  KCICFG     mt  ""   pmserver kcicfg     1440   1000  3     "00|04"            "src|dest"              N \
  AEMSC10MIN mt  ""   bsc      aemsc10min 10     1000  3     "0,10,20,30,40,50" "src|dest"              N \
  EVDOCONFIGMAP   mt  ""   evdo    evdoconfigmap     1440   336   3     "0,30"          "src|dest"      N

#  Number of MTPROCS attributes
NA_MTPROCS=11

#  Motorola monitor process required info
#   DA         PROGRAM                  DIRECTORY
#  PROCESS     NAME             LOG             DATA
#  ----------  --------------  ------   -------------------
set -A TMM_mon                                                \
   READER    mp_emis_reader      "get"            "|"                \
   PARSER    tmm_file            "fmt"            "src|dest|fmt"

set -A CDL_mon                                               \
   READER    fetch_cdl.pl        "|"       "src|dest"


# Initialize local variable
unset d_market d_tdir d_srcip d_srcid d_mmid d_srcdir d_sduid d_sdurecs d_vpuid d_vpurecs
unset d_anid d_anrecs d_svuid d_svurecs
unset d_cfgdir d_srcuser d_nogrps d_port d_mtxtbls d_chgpswd d_moncfg
unset d_ashell d_bshell d_mtopts d_tmadj d_monopt d_omfnames d_omshowinfo
unset d_nodeid d_rdfcfg d_bdfdel d_cbrscfg d_cbrsname d_svrname d_filedelay d_cycle
unset d_spooldir d_spool d_fodelay d_foserver
unset d_collminute d_collhour
unset d_redunip d_redunuser d_redunpaswd d_redundir
unset d_pastdays d_cfgname d_mscname
unset d_securecollect d_securedeliver
unset d_blockdir d_dbloadctrl

# Validate the setup config file and populate array
check_cfg_file $cfgfile

# Open a file descriptor for the cron file
cron_file=$CFGDIR/${lhost[0]}.mtcdma.cron

    fd_cron=4
    create_file $fd_cron $cron_file

# Loop through each type and make the setup

ans=0
j=0
while (($j < ${#d_market[*]}))
do
    p=0
    unset mt_opt
    set -A mt_opt $(echo ${d_mtopts[$j]} | tr "," " ")
    while (($p < ${#mt_opt[*]}))
    do
        # Get common information for each mtcdma option
        unset c_optname c_vendor c_datasrv c_netype c_dtype
        unset c_period c_entries c_retries c_crontm c_ddir c_monproc
        unset found nename
        unset m_procname m_progname m_ldir m_ddir mlogdir mdatadir
        unset tlogdir tdatadir

        # Validate option type
        found=0
        x=0
        while (($x < ${#MTPROCS[*]}))
        do
            if [ "${mt_opt[$p]}" == "${MTPROCS[$x]}" ]
            then
                found=1;
                break;
            else
                ((x=x+$NA_MTPROCS))
            fi
        done

        if [ $found == 0 ]
        then
            echo "${cmd}: ${mt_opt[$p]} is not a supported mtcdma option type"
            ((p=p+1))
            continue
        fi

        # Get the MTPROCS common info
        c_optname=${MTPROCS[$x]}; ((x=x+1))
        c_vendor=${MTPROCS[$x]};  ((x=x+1))
        c_datasrv=${MTPROCS[$x]}; ((x=x+1))
        c_netype=${MTPROCS[$x]};  ((x=x+1))
        c_dtype=${MTPROCS[$x]};   ((x=x+1))
        c_period=${MTPROCS[$x]};  ((x=x+1))
        c_entries=${MTPROCS[$x]}; ((x=x+1))
        c_retries=${MTPROCS[$x]}; ((x=x+1))
        set -A c_crontm $(echo ${MTPROCS[$x]} | tr "|" " "); ((x=x+1))
        c_ddir=${MTPROCS[$x]};  ((x=x+1))
        typeset -u c_monproc=${MTPROCS[$x]}; ((x=x+1))

        # Create FlexDA monitor log and data directories
        if [ "${c_monproc}" == "Y" ]
        then
            n=0
            set -A d_monopt "${d_monopt} $c_optname"
            set -A mon_detail $(eval echo \$\{$c_optname\_mon[*]})

            if ([ ${#mon_detail[*]} == 0 ] || \
                [ `expr ${#mon_detail[*]} % 4` != 0 ])
            then
                echo "${cmd}: ${c_optname}_mon not specified properly."
                exit 1
            fi

            i=0
            while (($n < ${#mon_detail[*]}))
            do
                m_procname=${mon_detail[$n]};   ((n=n+1))
                m_progname=${mon_detail[$n]};   ((n=n+1))
                m_ldir=${mon_detail[$n]};     ((n=n+1))
                m_ddir=${mon_detail[$n]};     ((n=n+1))

                ((i=i+1))
            done
        fi

        nename=${d_srcid[$j]}
        jobname=${d_market[$j]}.${nename}.${c_optname}
        if [ "${c_datasrv}" != "" ]
        then
            datasrv_field="_${c_datasrv}${d_datasrvid[$j]}"
        else
            datasrv_field=""
        fi

        edir=${d_market[$j]}
        tdir=${c_optname}

        #
        # Make required directories
        #

        tlogdir=${LOGDIR}/${edir}
        tdatadir=${DATADIR}/${edir}/${d_srcid[$j]}/${tdir}

        for dir in $(echo $c_ddir | tr "|" " ")
        do
           set -A mdatadir "${mdatadir[*]} ${dir}"
        done

        #
        # Append monitor log and data directory
        #

        if [ -n "${mdatadir[*]}" ]
        then
            unset ddir
            for dir in ${mdatadir[*]}; do
                ddir="$ddir $tdatadir/$dir"
            done

            tdatadir="$tdatadir $ddir"
        fi

        for dir in $tlogdir $tdatadir
        do
            if [ ! -d $dir ]
            then
                echo "${cmd}: making directory $dir"
                mkdir -p $dir
            fi
        done


        #
        # Creates .chk and .icf file
        #

        chkfname=$jobname.chk
        icffname=$jobname.icf
        cfgfname=$jobname.cfg

		if [ ! -f $LOGDIR/$chkfname ]
	    then
	        ans=1
	    else
	        ans=0
	    fi

	    if [ "$c_optname" == "EVDOPM" ] || [ "$c_optname" == "EVDOCDL" ] || [ "$c_optname" == "EVDOECDL" ] || [ "$c_optname" == "EVDOPMEMH" ]
	    then
	        c_period=${d_cycle[$j]}
	    fi

		if [ ans -eq 1 ]
		then
		    create_file 0 $LOGDIR/$chkfname
		    icf_create -n $c_entries -r $c_retries \
			$c_period $LOGDIR/$chkfname
		fi


	        if [ "$c_optname" == "TMM" ] || [ "$c_optname" == "CDL" ]
	        then
                cfd=6
				create_file $cfd $CFGDIR/$cfgfname
	        fi

	        if [ "$c_optname" != "CDL" ]
	        then
                fd=5
				create_file $fd $CFGDIR/$icffname

                #
                # Prints ICF header info
                #

                typeset -u title="$c_vendor $c_netype$c_optname Data Transfer"
                print_common_icf $fd "$title" "${d_market[$j]}" "$c_optname" \
                "${d_srcid[$j]}" "$c_dtype"
	        fi

            case  $c_optname in
                SMTM )
                    print_smtm_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_swid[$j]} \
                        ${d_behind[$j]} ${d_delay[$j]} ${d_timeout[$j]} \
                        ${d_ignbef[$j]} ${d_ignaft[$j]} ${d_version[$j]} \
                        ${d_smrepddcfg[$j]} ${d_smscriptsdir[$j]} \
                        ${lhost[1]} ${d_pastdays[$j]}
                        ;;

                TMM )
                    print_tmm_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_port[$j]} \
                        ${d_behind[$j]} ${d_delay[$j]} ${d_timeout[$j]} \
                        ${d_linkpair[$j]} ${d_ch[$j]} ${d_c0[$j]} \
                        ${d_minbef[$j]} ${d_minaft[$j]} \
		                ${d_ignbef[$j]} ${d_ignaft[$j]} ${d_maxretry[$j]} \
		                ${lhost[1]} ${d_pastdays[$j]}
                    print_tmm_cfg $cfd ${d_emisport[$j]} \
                        ${d_market[$j]} ${d_srcid[$j]} $c_optname \
                        ${FLEXDAHOME}
                        ;;

                CFG )
                    print_emxcfg_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_timeout[$j]} \
                        ${d_maxretry[$j]} ${lhost[1]} ${d_port[$j]} ${d_pastdays[$j]}
                        ;;

                CPU )
                    print_emxcpu_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_timeout[$j]} \
                        ${d_maxretry[$j]} ${lhost[1]} ${d_port[$j]} \
                        ${d_rptint[$j]} ${d_pastdays[$j]}
                        ;;

                PM )
                    print_omcrpm_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_pmdir[$j]} ${d_omcrcfg[$j]} \
                        ${d_mmid[$j]} ${lhost[1]} ${d_srcdir[$j]} \
			            ${d_srcid[$j]} ${d_sduid[$j]} ${d_sdurecs[$j]} \
		            	${d_vpuid[$j]} ${d_vpurecs[$j]} \
		            	${d_anid[$j]} ${d_anrecs[$j]} \
                        ${d_svurecs[$j]} ${d_pmcfgrecs[$j]} \
	            		${d_rawdir[$j]} ${d_rawnday[$j]} ${d_scol[$j]} ${d_sdel[$j]} \
	            		${d_pastdays[$j]} ${d_blockdir[$j]} ${d_dbloadctrl[$j]}
                        ;;

                ANPM10MIN )
                    print_anpm10min_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_sdir[$j]} \
                        ${d_pmdir[$j]} ${d_omcrcfg[$j]} ${d_svrname[$j]} \
                        ${lhost[1]} ${d_scol[$j]} ${d_sdel[$j]} ${d_rawdir[$j]} \
                        ${d_rawnday[$j]} ${d_anid[$j]} ${d_anrecs[$j]} \
                        ${d_pastdays[$j]} ${d_remotedir[$j]} ${d_blockdir[$j]} ${d_dbloadctrl[$j]}
                        ;;

                CDF )
                    print_omcrcdf_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_cdfdir[$j]} ${d_srcdir[$j]} \
                        ${d_omcrcfg[$j]} ${lhost[1]} \
		            	${d_scol[$j]} ${d_sdel[$j]} \
		            	${d_pastdays[$j]}
                        ;;


                NECF )
                    print_omcrnecf_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_cdfdir[$j]} ${d_srcdir[$j]} \
                        ${d_omcrcfg[$j]} ${lhost[1]} \
	            		${d_scol[$j]} ${d_sdel[$j]} ${d_srcid[$j]} \
	            		${d_pastdays[$j]}
                        ;;

                CDL )
                    print_omcrcdl_cfg $cfd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]}  ${d_port[$j]} \
                        ${d_omcrcfg[$j]} ${lhost[1]} \
	          	        ${d_market[$j]} ${d_srcid[$j]} $c_optname \
	           	        $FLEXDAHOME ${d_cdlsleep[$j]} ${d_delaygap[$j]}
                        ;;

                SAR )
                    print_sar_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_behind[$j]} \
                        ${d_sdir[$j]} ${lhost[1]} \
		            	${d_scol[$j]} ${d_sdel[$j]} \
	            		${d_rawdir[$j]} ${d_rawnday[$j]} ${d_pastdays[$j]}
                        ;;

                EVDOPM )
                    print_evdopm_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_sdir[$j]} \
                        ${d_svrname[$j]} ${d_filedelay[$j]} ${d_cycle[$j]} \
                        ${d_behind[$j]} ${lhost[1]} ${d_scol[$j]} \
                        ${d_sdel[$j]} ${d_spooldir[$j]} ${d_spool[$j]} \
                        ${d_fodelay[$j]}  ${d_foserver[$j]} ${d_redunip[$j]}  \
                        ${d_redunuser[$j]} ${d_redunpaswd[$j]} \
                        ${d_redundir[$j]} ${d_pastdays[$j]}
                        ;;

                EVDOPMEMH )
                    print_evdopmemh_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_sdir[$j]} \
                        ${d_svrname[$j]} ${d_filedelay[$j]} ${d_cycle[$j]} \
                        ${d_behind[$j]} ${lhost[1]} ${d_scol[$j]} \
                        ${d_sdel[$j]} ${d_spooldir[$j]} ${d_spool[$j]} \
                        ${d_pastdays[$j]}
                        ;;

                EVDOCDL )
                    print_evdocdl_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_sdir[$j]} \
	            		${d_svrname[$j]} ${d_filedelay[$j]} ${d_cycle[$j]} \
	            		${d_behind[$j]} ${lhost[1]} \
            			${d_scol[$j]} ${d_sdel[$j]} \
			            ${d_spooldir[$j]} ${d_spool[$j]} \
            			${d_fodelay[$j]}  ${d_foserver[$j]} \
						${d_redunip[$j]}  ${d_redunuser[$j]} \
						${d_redunpaswd[$j]} ${d_redundir[$j]} ${d_pastdays[$j]}
                        ;;

                PMSERVER )
                    print_pmserver_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_pmdir[$j]} \
                        ${lhost[1]} ${d_srcdir[$j]} \
			            ${d_srcid[$j]} ${d_scol[$j]} ${d_sdel[$j]} \
			            ${d_pastdays[$j]} ${d_blockdir[$j]} ${d_dbloadctrl[$j]}
                        ;;

                KCICFG )
                    print_kcicfg_icf $fd ${d_tdir[$j]} ${d_srcip[$j]} \
                        ${d_srcid[$j]} ${d_srcuser[$j]} ${d_srcpswd[$j]} \
                        ${d_srcdir[$j]} ${d_cfgname[$j]} \
                        ${d_spool[$j]} ${d_spooldir[$j]} ${d_collminute[$j]} \
                        ${d_collhour[$j]} ${d_rawnday[$j]} \
                        ${d_scol[$j]} ${d_sdel[$j]} ${d_pastdays[$j]}
                        ;;

                AEMSC13 | AEMSC2 | AEMSC4 | AEMSC6 )
                    print_aemsc_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_pmdir[$j]} \
                        ${lhost[1]} ${d_srcdir[$j]} \
            			${d_srcid[$j]} ${d_scol[$j]} ${d_sdel[$j]} \
            			${d_pastdays[$j]} ${d_blockdir[$j]} ${d_dbloadctrl[$j]}
                        ;;

                AEMSC10MIN )
                    print_aemsc10min_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_pmdir[$j]} \
                        ${lhost[1]} ${d_srcdir[$j]} \
            			${d_srcid[$j]} ${d_scol[$j]} ${d_sdel[$j]} \
            			${d_pastdays[$j]} ${d_blockdir[$j]} ${d_dbloadctrl[$j]}
                        ;;

                  EVDOCONFIGMAP )
                    print_evdoconfig_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_sdir[$j]} \
                        ${d_svrname[$j]}  ${d_behind[$j]} ${lhost[1]} \
                        ${d_scol[$j]} ${d_sdel[$j]} \
                        ${d_spooldir[$j]} ${d_spool[$j]} ${d_innerfiledir_f[$j]}
                        ;;

                * ) echo "${cmd}: $c_optname not supported";;
             esac


             #
             # Prints Prospect target host info
             #

	     if [ "$c_optname" == "CDL" ]
	     then
               print_thost_icf_cdl $cfd ${thost[1]} ${thost[2]} ${thost[3]} ${d_tdir[$j]}
	     else
               print_thost_icf $fd ${thost[1]} ${thost[2]} ${thost[3]} ${d_tdir[$j]}
	     fi


         #
         # Add cron entry in crontab file
         #

         mi=${c_crontm[0]:-*}
         hr=${c_crontm[1]:-*}
         dm=${c_crontm[2]:-*}
         my=${c_crontm[3]:-*}
         dw=${c_crontm[4]:-*}

         tlogdir=`echo $tlogdir|sed "s/ .*$//"`

	 #
	 # Data export cycles for EVDOPM,EVDOCDL and EVDOECDL are configurable
	 # The crontab time should be i*$cycle + filedelay + 1
	 #
	 if [ "$c_optname" == "EVDOPM" ] || [ "$c_optname" == "EVDOCDL" ] || [ "$c_optname" == "EVDOPMEMH" ]
	 then
	     i=0;
	     unset mi
	     while (( $i < (60 / ${d_cycle[$j]}) ))
	     do
		     ((adm=i * d_cycle[j] + d_filedelay[j] + 1))
                     if [ $adm -gt 60 ]
                     then
                         ((adm=$adm - 60))
                     fi

		     if [ $i == 0 ]
		     then
		         mi="$adm"
		     else
		         mi="$mi,$adm"
		     fi
        	((i=i+1))
	     done
	 fi

 	 #
	 # Hour and minutes field for KCICFG are configurable
	 #

	 if [ "$c_optname" == "KCICFG" ]
	 then

	     if test "${d_collminute[$j]}" != ""
	     then
	         mi="${d_collminute[$j]}"
	     fi

	     if test "${d_collhour[$j]}" != ""
	     then
	         hr="${d_collhour[$j]}"
	     fi
	 fi

	 if [ $fd_cron ] && [ -n $fd_cron ] && [ "$c_optname" != "CDL" ]
     then
        print -u$fd_cron "$mi $hr $dm $my $dw ksh -c \". $FLEXDAHOME/.kshrc; icf_chat.exp $icffname -L $tlogdir,${d_market[$j]}.${d_srcid[$j]}.$c_optname.,.log,1440,40000,7\""
     fi

    ((p=p+1))
    done
((j=j+1))
done

#
# Creates FlexDA monitor configuration file
#

typeset opt=$(echo ${d_monopt[*]} |tr " " "\n" |sort -u)
typeset -l servername=${lhost[0]}
typeset -l monfname="mtcdma.mon"
typeset -l vndrmonfname="mtcdma.cmon"


    fd_mon=9
    create_file $fd_mon $CFGDIR/$vndrmonfname

    print_Motorola_mon $fd_mon "$opt" ${servername}

	cat /dev/null | tee $CFGDIR/$monfname
	cat $CFGDIR/$vndrmonfname >> $CFGDIR/$monfname

cd $CFGDIR
cat ${HOST}.*.cron > ${HOST}.cron

#
# Remove the duplicated FlexDA system health check jobs
# Note: Append after all vendor specific cronjobs.
#

STR_CHECK_ERROR="check_error\.pl"
STR_PAGE_ERROR="page_error\.pl"

grep -v ${STR_CHECK_ERROR} ${HOST}.cron | grep -v ${STR_PAGE_ERROR} > ${HOST}.cron.$$
mv ${HOST}.cron.$$ ${HOST}.cron

#
# Add FlexDA system health check jobs at the end of cronjobs,
# outside all vendor-specific cronjob blocks
#

echo "0,30 * * * * ksh -c \". $FLEXDAHOME/.kshrc; check_error.pl\"" >> ${HOST}.cron
echo "1,31 * * * * ksh -c \". $FLEXDAHOME/.kshrc; page_error.pl\"" >> ${HOST}.cron

if [ -d $SAVEDIR ]
then
	echo "${cmd}: Files backup in ${SAVEDIR}"
fi

echo "${cmd}: Done!"
